IndirectCount

Struct IndirectCount 

#[repr(C)]
pub struct IndirectCount { pub count_x: u32, pub count_y: u32, pub count_z: u32, pub pad0: u32, }
Storage of indirect dispatch size values.

The original plan was to reuse BumpAllocators, but the WebGPU compatible usage list rules forbid that being used as indirect counts while also bound as writable.

Fields

count_x: u32count_y: u32count_z: u32pad0: u32