pub fn resolve_solid_paths_only(
encoding: &Encoding,
packed: &mut Vec<u8>,
) -> LayoutExpand description
Resolves and packs an encoding that contains only paths with solid color fills.
Panics if the encoding contains any late bound resources (gradients, images or glyph runs).