#[repr(C)]pub struct DrawBeginClip {
pub blend_mode: u32,
pub alpha: f32,
}Expand description
Draw data for a clip or layer.
Fields
blend_mode: u32Blend mode.
alpha: f32Group alpha.
Implementations
Sourceimpl DrawBeginClip
impl DrawBeginClip
Sourcepub const LUMINANCE_MASK_BLEND_MODE: u32 = 0x10000
pub const LUMINANCE_MASK_BLEND_MODE: u32 = 0x10000
The blend_mode used to indicate that a layer should be
treated as a luminance mask.
The least significant 16 bits are reserved for Mix + Compose combinations.
Sourcepub const CLIP_BLEND_MODE: u32 = 0x8003
pub const CLIP_BLEND_MODE: u32 = 0x8003
The blend_mode used to indicate that a layer should be
treated as a clip.
This is equivalent to Compose::SrcOver with a Mix of 128,
for legacy reasons.
We expect this to change in the future.
Sourcepub fn new(blend_mode: BlendMode, alpha: f32) -> Self
pub fn new(blend_mode: BlendMode, alpha: f32) -> Self
Creates new clip draw data for a Porter-Duff blend mode.
Sourcepub fn luminance_mask(alpha: f32) -> Self
pub fn luminance_mask(alpha: f32) -> Self
Creates a new clip draw data for a luminance mask.